2021-10-11

    * Version 1.4.0
    * Drop support for Python 2, add support for Flask 2

2014-10-06  horneds

    * Version 1.0.5
    * Support filters, support link storage, avoid duplicates

2014-04-22  horneds

    * Version 0.2.3
    * Code cleanup

2014-02-09  jirikuncar (Jiri Kuncar)

    * Version 0.2.2
    * Copy App's Static Files

2013-08-01  horneds

    * Version 0.2.1
    * Support python3

2012-09-02  klen

    * Version 0.1.6
    * Add docs

2012-08-18  klen

    * Version 0.1.4

2012-08-12  klen

    * Version 0.1.3
    * More information in verbose mode

2012-08-05  klen

    * Initial release 0.1.1
